@@ -5,7 +5,9 @@
 #include <QDebug>
 #include <QFileDialog>
 #include <QDateTime>
-#include <QMaemo5InformationBox>
+#if defined(Q_WS_MAEMO_5)
+    #include <QMaemo5InformationBox>
+#endif
 #include <QtGui>
 
 MainWindow::MainWindow(QWidget *parent) :
@@ -30,7 +32,9 @@ MainWindow::MainWindow(QWidget *parent) :
     header << "Name" << "Size" << "Status" << "Completed";
     ui->lstHistory->setHeaderLabels(header);
 
-    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+    #if defined(Q_WS_MAEMO_5)
+        setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+    #endif
     //add menubar items
     QAction *settingsAction = new QAction(tr("Settings"), this);
     menuBar()->addAction(settingsAction);
@@ -124,7 +128,11 @@ void MainWindow::on_pbHistory_clicked()
 
 void MainWindow::showError(QString error)
 {
-    QMaemo5InformationBox::information(this, error, QMaemo5InformationBox::DefaultTimeout);
+    #if defined(Q_WS_MAEMO_5)
+        QMaemo5InformationBox::information(this, error, QMaemo5InformationBox::DefaultTimeout);
+    #else
+        QMessageBox::information(this,"Error occured.",error);
+    #endif
 }
 
 void MainWindow::updateHistoryList(QMap<QString,QMap<QString,QString > > historyitems)
